package com.vaadin.demo.tutorial.addressbook.ui;

import com.vaadin.data.Property.ValueChangeEvent;
import com.vaadin.data.Property.ValueChangeListener;
import com.vaadin.demo.tutorial.addressbook.AddressBookUI;
import com.vaadin.demo.tutorial.addressbook.data.PersonContainer;
import com.vaadin.demo.tutorial.addressbook.data.SearchFilter;
import com.vaadin.ui.Button;
import com.vaadin.ui.Button.ClickEvent;
import com.vaadin.ui.CheckBox;
import com.vaadin.ui.FormLayout;
import com.vaadin.ui.Layout;
import com.vaadin.ui.NativeSelect;
import com.vaadin.ui.Notification;
import com.vaadin.ui.Panel;
import com.vaadin.ui.TextField;
import com.vaadin.ui.VerticalLayout;

@SuppressWarnings("serial")
public class SearchView extends Panel {

  private TextField tf;
  private NativeSelect fieldToSearch;
  private CheckBox saveSearch;
  private TextField searchName;
  private AddressBookUI app;

  public SearchView(final AddressBookUI app) {
    this.app = app;
    addStyleName("view");

    setCaption("Search contacts");
    setSizeFull();

    /* Use a FormLayout as main layout for this Panel */
    FormLayout formLayout = new FormLayout();
    setContent(formLayout);

    /* Create UI components */
    tf = new TextField("Search term");
    fieldToSearch = new NativeSelect("Field to search");
    saveSearch = new CheckBox("Save search");
    searchName = new TextField("Search name");
    Button search = new Button("Search");

    /* Initialize fieldToSearch */
    for (int i = 0; i < PersonContainer.NATURAL_COL_ORDER.length; i++) {
      fieldToSearch.addItem(PersonContainer.NATURAL_COL_ORDER[i]);
      fieldToSearch.setItemCaption(PersonContainer.NATURAL_COL_ORDER[i], PersonContainer.COL_HEADERS_ENGLISH[i]);
    }

    fieldToSearch.setValue("lastName");
    fieldToSearch.setNullSelectionAllowed(false);

    /* Initialize save checkbox */
    saveSearch.setValue(true);
    saveSearch.setImmediate(true);
    saveSearch.addValueChangeListener(new ValueChangeListener() {

      @Override
      public void valueChange(ValueChangeEvent event) {
        searchName.setVisible(!searchName.isVisible());
      }
    });

    search.addClickListener(new Button.ClickListener() {
      public void buttonClick(ClickEvent event) {
        performSearch();
      }

    });

    /* Add all the created components to the form */
    Layout l = new VerticalLayout();
    l.addComponent(tf);
    l.addComponent(fieldToSearch);
    l.addComponent(saveSearch);
    l.addComponent(searchName);
    l.addComponent(search);
    setContent(l);
  }

  private void performSearch() {
    String searchTerm = (String) tf.getValue();
    if (searchTerm == null || searchTerm.equals("")) {
      Notification.show("Search term cannot be empty!", Notification.Type.WARNING_MESSAGE);
      return;
    }

    SearchFilter searchFilter = new SearchFilter(fieldToSearch.getValue(), searchTerm, (String) searchName.getValue());
    if ((Boolean) saveSearch.getValue()) {
      if (searchName.getValue() == null || searchName.getValue().equals("")) {
        Notification.show("Please enter a name for your search!", Notification.Type.WARNING_MESSAGE);
        return;
      }
      app.saveSearch(searchFilter);
    }
    app.search(searchFilter);
  }

}